"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MenuGroupRenderer = void 0;
var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _react = _interopRequireWildcard(require("react"));
var _store = _interopRequireDefault(require("store"));
var _emotion = require("emotion");
var _reactTransitionGroup = require("react-transition-group");
var _classnames = _interopRequireDefault(require("classnames"));
var _reactRouter = require("@webiny/react-router");
var _appAdmin = require("@webiny/app-admin");
var _List = require("@webiny/ui/List");
var _Button = require("@webiny/ui/Button");
var _index = require("../index");
var _roundKeyboard_arrow_up24px = require("../icons/round-keyboard_arrow_up-24px.svg");
var _roundKeyboard_arrow_down24px = require("../icons/round-keyboard_arrow_down-24px.svg");
var defaultStyle = {
  transform: "translateY(-20px)",
  opacity: 0,
  transitionProperty: "transform, opacity",
  transitionTimingFunction: "cubic-bezier(0, 0, .2, 1)",
  transitionDuration: "100ms",
  willChange: "opacity, transform"
};
var transitionStyles = {
  entering: {
    transform: "translateY(-20px)",
    opacity: 0
  },
  entered: {
    transform: "translateY(0px)",
    opacity: 1
  }
};
var menuTitle = /*#__PURE__*/(0, _emotion.css)({
  ".mdc-drawer &.mdc-list": {
    borderBottom: "1px solid var(--mdc-theme-on-background)",
    padding: 0,
    ".mdc-list-item": {
      margin: 0,
      padding: "0 15px",
      height: "48px",
      width: "100%",
      fontWeight: 600,
      boxSizing: "border-box"
    }
  }
}, "label:menuTitle;");
var menuTitleActive = /*#__PURE__*/(0, _emotion.css)({
  backgroundColor: "var(--mdc-theme-background)"
}, "label:menuTitleActive;");
var LOCAL_STORAGE_KEY = "webiny_navigation_groups";
function loadState() {
  return (_store.default.get(LOCAL_STORAGE_KEY) || "").split(",").filter(Boolean);
}
function storeState(state) {
  _store.default.set(LOCAL_STORAGE_KEY, state.join(","));
}
function getState(id) {
  if (!id) {
    return false;
  }
  var state = loadState();
  return state.includes(id);
}
var MenuGroupRenderer = function MenuGroupRenderer(PrevMenuItem) {
  return function MenuGroup() {
    var _useNavigation = (0, _index.useNavigation)(),
      setVisible = _useNavigation.setVisible;
    var _useMenuItem = (0, _appAdmin.useMenuItem)(),
      menuItem = _useMenuItem.menuItem,
      depth = _useMenuItem.depth;
    var shouldRender = depth === 0 && menuItem && menuItem.children;
    var _useState = (0, _react.useState)(getState(menuItem ? menuItem.name : null)),
      _useState2 = (0, _slicedToArray2.default)(_useState, 2),
      isExpanded = _useState2[0],
      setExpanded = _useState2[1];
    var hideMenu = (0, _react.useCallback)(function () {
      return setVisible(false);
    }, []);
    var toggleElement = (0, _react.useCallback)(function () {
      if (!menuItem) {
        return;
      }
      var state = loadState();
      if (isExpanded && state.includes(menuItem.name)) {
        state.splice(state.indexOf(menuItem.name), 1);
      }
      if (!isExpanded && !state.includes(menuItem.name)) {
        state.push(menuItem.name);
      }
      setExpanded(!isExpanded);
      storeState(state);
    }, [isExpanded, setExpanded]);
    if (!shouldRender) {
      return /*#__PURE__*/_react.default.createElement(PrevMenuItem, null);
    }
    if (!menuItem || !menuItem.children.length) {
      return null;
    }
    var withLink = function withLink(content) {
      return /*#__PURE__*/_react.default.createElement(_reactRouter.Link, {
        to: menuItem.path || "",
        "data-testid": menuItem.testId,
        onClick: menuItem.onClick || hideMenu
      }, content);
    };
    var item = /*#__PURE__*/_react.default.createElement(_List.List, {
      className: (0, _classnames.default)(menuTitle, (0, _defineProperty2.default)({}, menuTitleActive, isExpanded))
    }, /*#__PURE__*/_react.default.createElement(_List.ListItem, {
      "data-testid": menuItem.testId,
      onClick: toggleElement
    }, menuItem.icon && /*#__PURE__*/_react.default.createElement(_List.ListItemGraphic, null, /*#__PURE__*/_react.default.createElement(_Button.IconButton, {
      icon: menuItem.icon
    })), menuItem.label, menuItem.children.length ? /*#__PURE__*/_react.default.createElement(_List.ListItemMeta, null, /*#__PURE__*/_react.default.createElement(_Button.IconButton, {
      icon: isExpanded ? /*#__PURE__*/_react.default.createElement(_roundKeyboard_arrow_up24px.ReactComponent, null) : /*#__PURE__*/_react.default.createElement(_roundKeyboard_arrow_down24px.ReactComponent, null)
    })) : null));
    return /*#__PURE__*/_react.default.createElement(_react.Fragment, null, menuItem.path ? withLink(item) : item, menuItem.children ? /*#__PURE__*/_react.default.createElement(_reactTransitionGroup.Transition, {
      in: isExpanded,
      timeout: 100,
      appear: true,
      unmountOnExit: true
    }, function (state) {
      return /*#__PURE__*/_react.default.createElement("div", {
        style: (0, _objectSpread2.default)((0, _objectSpread2.default)({}, defaultStyle), transitionStyles[state])
      }, /*#__PURE__*/_react.default.createElement(_appAdmin.MenuItems, {
        menuItems: menuItem.children
      }));
    }) : null);
  };
};
exports.MenuGroupRenderer = MenuGroupRenderer;

//# sourceMappingURL=MenuGroupRenderer.js.map