"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.OmniSearch = void 0;
var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
var _react = _interopRequireWildcard(require("react"));
var _appAdmin = require("@webiny/app-admin");
var _reactRouter = require("@webiny/react-router");
var _utils = require("@webiny/app/utils");
var _search = require("@material-design-icons/svg/outlined/search.svg");
var _reactHotkeyz = require("react-hotkeyz");
var _Input = require("@webiny/ui/Input");
var _Typography = require("@webiny/ui/Typography");
var _Dialog = require("./OmniSearch/Dialog");
/**
 * Library does not have types.
 */ // @ts-expect-error
var getIndexedItemsList = function getIndexedItemsList(items) {
  var lastUsedItemIndex = 0;
  return items.map(function (itemsSection) {
    return (0, _objectSpread2.default)((0, _objectSpread2.default)({}, itemsSection), {}, {
      items: itemsSection.items.map(function (item) {
        var index = lastUsedItemIndex++;
        return (0, _objectSpread2.default)((0, _objectSpread2.default)({}, item), {}, {
          index: index
        });
      })
    });
  });
};
var getItemFromIndexedItemsList = function getItemFromIndexedItemsList(itemsSections, index) {
  if (index < 0) {
    return null;
  }
  for (var i = 0; i < itemsSections.length; i++) {
    var itemsSection = itemsSections[i];
    for (var j = 0; j < itemsSection.items.length; j++) {
      var item = itemsSection.items[j];
      if (item.index === index) {
        return item;
      }
    }
  }
  return null;
};
var OmniSearch = function OmniSearch() {
  var _useState = (0, _react.useState)(false),
    _useState2 = (0, _slicedToArray2.default)(_useState, 2),
    omniSearchVisible = _useState2[0],
    setShowOmniSearch = _useState2[1];
  var _useState3 = (0, _react.useState)(),
    _useState4 = (0, _slicedToArray2.default)(_useState3, 2),
    itemRender = _useState4[0],
    setItemRender = _useState4[1];
  var _useState5 = (0, _react.useState)(""),
    _useState6 = (0, _slicedToArray2.default)(_useState5, 2),
    filter = _useState6[0],
    setFilter = _useState6[1];
  var _useState7 = (0, _react.useState)(0),
    _useState8 = (0, _slicedToArray2.default)(_useState7, 2),
    focusedItemIndex = _useState8[0],
    focusItemAtIndex = _useState8[1];
  var _useNavigation = (0, _appAdmin.useNavigation)(),
    menuItems = _useNavigation.menuItems;
  var _useSnackbar = (0, _appAdmin.useSnackbar)(),
    showSnackbar = _useSnackbar.showSnackbar;
  var navigate = (0, _reactRouter.useNavigate)();
  var showOmniSearch = (0, _react.useCallback)(function () {
    setShowOmniSearch(true);
  }, []);
  var hideOmniSearch = (0, _react.useCallback)(function () {
    setShowOmniSearch(false);
    setItemRender(undefined);
    setFilter("");
  }, []);
  var onFilter = (0, _react.useCallback)(function (searchString) {
    setFilter(searchString);
    focusItemAtIndex(0);
  }, []);
  var selectItem = (0, _react.useCallback)(function (item) {
    if (item.link) {
      navigate(item.link);
      hideOmniSearch();
      return;
    }
    if (item.callback) {
      item.callback();
      hideOmniSearch();
      return;
    }
    if (item.render) {
      setFilter("");
      setItemRender(function () {
        return item.render;
      });
    }
  }, []);

  // TODO: should be pulled from registered plugins.
  var fullItemsList = (0, _react.useMemo)(function () {
    return [{
      id: "apps",
      title: "Apps",
      items: (0, _toConsumableArray2.default)(menuItems.map(function (level1Item) {
        return (0, _toConsumableArray2.default)(level1Item.children.map(function (level2Item) {
          return (0, _toConsumableArray2.default)(level2Item.children.map(function (child) {
            var description = [level1Item.label, level2Item.label].join(" / ");
            return {
              id: description + child.label,
              title: child.label,
              description: description,
              link: child.path
            };
          }));
        })).flat();
      }).flat())
    }, {
      id: "other",
      title: "Other",
      items: [{
        id: "back",
        title: "← Back",
        description: "Navigates to the previous page.",
        callback: function callback() {
          navigate(-1);
        }
      }]
    }, (0, _utils.getTenantId)() && {
      id: "development",
      title: "Development",
      items: [{
        id: "copy-tenant-id",
        title: "Copy current tenant ID",
        description: "Copies current tenant ID into clipboard.",
        callback: function callback() {
          navigator.clipboard.writeText((0, _utils.getTenantId)());
          showSnackbar("Tenant ID copied to clipboard.");
        }
      }]
    }].filter(Boolean);
  }, [menuItems]);
  var filteredIndexedItemsList = (0, _react.useMemo)(function () {
    if (!filter) {
      return getIndexedItemsList(fullItemsList);
    }
    var filteredItems1stPass = fullItemsList.map(function (itemsSection) {
      return (0, _objectSpread2.default)((0, _objectSpread2.default)({}, itemsSection), {}, {
        items: itemsSection.items.filter(function (item) {
          return item.title?.toLowerCase().includes(filter.toLowerCase());
        })
      });
    });
    var filteredItems2ndPass = filteredItems1stPass.filter(function (itemsSection) {
      return itemsSection.items.length > 0;
    });
    return getIndexedItemsList(filteredItems2ndPass);
  }, [fullItemsList, filter]);
  var selectFocusedItem = (0, _react.useCallback)(function () {
    var focusedItem = getItemFromIndexedItemsList(filteredIndexedItemsList, focusedItemIndex);
    if (focusedItem) {
      selectItem(focusedItem);
    }
  }, [filteredIndexedItemsList, focusedItemIndex]);
  var focusNextItem = (0, _react.useCallback)(function () {
    var nextIndex = focusedItemIndex + 1;
    var itemToFocus = getItemFromIndexedItemsList(filteredIndexedItemsList, nextIndex);
    if (itemToFocus) {
      focusItemAtIndex(itemToFocus.index);
    }
  }, [filteredIndexedItemsList, focusedItemIndex]);
  var focusPrevItem = (0, _react.useCallback)(function () {
    var prevIndex = focusedItemIndex - 1;
    var itemToFocus = getItemFromIndexedItemsList(filteredIndexedItemsList, prevIndex);
    if (itemToFocus) {
      focusItemAtIndex(itemToFocus.index);
    }
  }, [filteredIndexedItemsList, focusedItemIndex]);
  (0, _reactHotkeyz.useHotkeys)({
    zIndex: 1000,
    keys: {
      "mod+k": showOmniSearch,
      esc: hideOmniSearch
    }
  });
  (0, _reactHotkeyz.useHotkeys)({
    zIndex: 1000,
    keys: {
      enter: selectFocusedItem,
      arrowUp: focusPrevItem,
      arrowDown: focusNextItem
    },
    disabled: !omniSearchVisible
  });
  if (!omniSearchVisible) {
    return null;
  }
  var renderedResults = /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, "Nothing to show.");
  if (itemRender) {
    renderedResults = itemRender();
  } else if (filteredIndexedItemsList.length > 0) {
    renderedResults = /*#__PURE__*/_react.default.createElement("ul", null, filteredIndexedItemsList.map(function (itemsSection) {
      return /*#__PURE__*/_react.default.createElement("li", {
        key: itemsSection.id
      }, /*#__PURE__*/_react.default.createElement("div", {
        className: "section-title"
      }, /*#__PURE__*/_react.default.createElement(_Typography.Typography, {
        use: "overline"
      }, itemsSection.title)), /*#__PURE__*/_react.default.createElement("div", {
        className: "section-items"
      }, /*#__PURE__*/_react.default.createElement("ul", null, itemsSection.items.map(function (item) {
        var isFocused = item.index === focusedItemIndex;
        return /*#__PURE__*/_react.default.createElement("li", {
          className: isFocused ? "focused" : "",
          key: item.id,
          onClick: function onClick() {
            return selectFocusedItem();
          },
          onMouseEnter: function onMouseEnter() {
            return focusItemAtIndex(item.index);
          }
        }, /*#__PURE__*/_react.default.createElement("div", {
          className: "section-item-title"
        }, item.title), /*#__PURE__*/_react.default.createElement(_Typography.Typography, {
          use: "caption",
          className: "section-item-description"
        }, item.description));
      }))));
    }));
  }
  return /*#__PURE__*/_react.default.createElement(_Dialog.Dialog, null, /*#__PURE__*/_react.default.createElement("div", {
    className: "dialog"
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: "search-input"
  }, /*#__PURE__*/_react.default.createElement(_Input.Input, {
    icon: /*#__PURE__*/_react.default.createElement(_search.ReactComponent, null),
    placeholder: "Search...",
    autoFocus: true,
    value: filter,
    onChange: onFilter
  })), renderedResults));
};
exports.OmniSearch = OmniSearch;

//# sourceMappingURL=OmniSearch.js.map